@@ -1,19 +1,12 @@
-package Mail::Audit::MailInternet;
-
-=head1 NAME
-
-Mail::Audit::MailInternet - a Mail::Internet-based Mail::Audit object
-
-=cut
-
-# $Id: /my/icg/mail-audit/trunk/lib/Mail/Audit/MailInternet.pm 22026 2006-06-02T02:13:29.371409Z rjbs  $
-
 use strict;
-use Mail::Internet;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-@ISA = qw(Mail::Audit Mail::Internet);
+package Mail::Audit::MailInternet;
+{
+  $Mail::Audit::MailInternet::VERSION = '2.228';
+}
+# ABSTRACT: a Mail::Internet-based Mail::Audit object
 
-$VERSION = '2.227';
+use Mail::Internet;
+use parent qw(Mail::Audit Mail::Internet);
 
 sub _autotype_new {
   my $class = shift;
@@ -36,3 +29,42 @@ sub new {
 sub is_mime { 0; }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Mail::Audit::MailInternet - a Mail::Internet-based Mail::Audit object
+
+=head1 VERSION
+
+version 2.228
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Simon Cozens
+
+=item *
+
+Meng Weng Wong
+
+=item *
+
+Ricardo SIGNES
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2000 by Simon Cozens.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
